import { queryGenerator, mutationGenerator } from './chunk-QPJYCH77.js';
import './chunk-V5DEG2OQ.js';
import path from 'node:path';
import { createPlugin, FileManager, PluginManager } from '@kubb/core';
import { camelCase, pascalCase } from '@kubb/core/transformers';
import { renderTemplate } from '@kubb/core/utils';
import { pluginOasName, OperationGenerator } from '@kubb/plugin-oas';
import { pluginTsName } from '@kubb/plugin-ts';
import { pluginZodName } from '@kubb/plugin-zod';

var pluginSvelteQueryName = "plugin-svelte-query";
var pluginSvelteQuery = createPlugin((options) => {
  const {
    output = { path: "hooks" },
    group,
    exclude = [],
    include,
    override = [],
    parser = "client",
    transformers = {},
    pathParamsType = "inline",
    mutation = {},
    query = {}
  } = options;
  const template = group?.output ? group.output : `${output.path}/{{tag}}Controller`;
  return {
    name: pluginSvelteQueryName,
    options: {
      output: {
        exportType: "barrelNamed",
        ...output
      },
      baseURL: void 0,
      client: {
        importPath: "@kubb/plugin-client/client",
        dataReturnType: "data",
        pathParamsType: "inline",
        ...options.client
      },
      query: {
        key: (key) => key,
        methods: ["get"],
        importPath: "@tanstack/svelte-query",
        ...query
      },
      mutation: {
        methods: ["post", "put", "patch", "delete"],
        importPath: "@tanstack/svelte-query",
        ...mutation
      },
      pathParamsType,
      parser
    },
    pre: [pluginOasName, pluginTsName, parser === "zod" ? pluginZodName : void 0].filter(Boolean),
    resolvePath(baseName, pathMode, options2) {
      const root = path.resolve(this.config.root, this.config.output.path);
      const mode = pathMode ?? FileManager.getMode(path.resolve(root, output.path));
      if (mode === "single") {
        return path.resolve(root, output.path);
      }
      if (options2?.tag && group?.type === "tag") {
        const tag = camelCase(options2.tag);
        return path.resolve(root, renderTemplate(template, { tag }), baseName);
      }
      return path.resolve(root, output.path, baseName);
    },
    resolveName(name, type) {
      let resolvedName = camelCase(name);
      if (type === "file" || type === "function") {
        resolvedName = camelCase(name, {
          isFile: type === "file"
        });
      }
      if (type === "type") {
        resolvedName = pascalCase(name);
      }
      if (type) {
        return transformers?.name?.(resolvedName, type) || resolvedName;
      }
      return resolvedName;
    },
    async buildStart() {
      const [swaggerPlugin] = PluginManager.getDependedPlugins(this.plugins, [pluginOasName]);
      const oas = await swaggerPlugin.context.getOas();
      const root = path.resolve(this.config.root, this.config.output.path);
      const mode = FileManager.getMode(path.resolve(root, output.path));
      const baseURL = await swaggerPlugin.context.getBaseURL();
      const operationGenerator = new OperationGenerator(
        {
          ...this.plugin.options,
          baseURL
        },
        {
          oas,
          pluginManager: this.pluginManager,
          plugin: this.plugin,
          contentType: swaggerPlugin.context.contentType,
          exclude,
          include,
          override,
          mode
        }
      );
      const files = await operationGenerator.build(queryGenerator, mutationGenerator);
      await this.addFile(...files);
      if (this.config.output.exportType) {
        const barrelFiles = await this.fileManager.getBarrelFiles({
          root,
          output,
          files: this.fileManager.files,
          meta: {
            pluginKey: this.plugin.key
          },
          logger: this.logger
        });
        await this.addFile(...barrelFiles);
      }
    }
  };
});

export { pluginSvelteQuery, pluginSvelteQueryName };
//# sourceMappingURL=index.js.map
//# sourceMappingURL=index.js.map